# VectorsPY

Python module to use Vector2 and Vector3 (as in Unity Game Engine - C#) in Python.

- Create Vector2 objects for 2D Vectors (x and y coordinate system)
- Create Vector3 objects for 3D Vectors (x,y and z coordinate system)
- Add, Subtract 2 Vectors
- Get Magnitude of Vector Object<br>
and much more]

## Installation

Using pip - 
```
pip install VectorsPY
```